Syncto
======

|travis| |master-coverage| |readthedocs|

.. |travis| image:: https://travis-ci.org/mozilla-services/syncto.svg?branch=master
    :target: https://travis-ci.org/mozilla-services/syncto

.. |readthedocs| image:: https://readthedocs.org/projects/syncto/badge/?version=latest
    :target: http://syncto.readthedocs.org/en/latest/
    :alt: Documentation Status

.. |master-coverage| image::
    https://coveralls.io/repos/mozilla-services/syncto/badge.png?branch=master
    :alt: Coverage
    :target: https://coveralls.io/r/mozilla-services/syncto

Syncto is a server allowing you to store and retrieve Firefox Sync
user data attached to your Firefox account using the Kinto API in
order to be able to use Kinto.js for that task.

* `Online documentation <http://syncto.readthedocs.org/en/latest/>`_
* `Issue tracker <https://github.com/mozilla-services/syncto/issues>`_
